Tutorials
=================

Some of the subject Tomni deals with need context to be fully understood.
Only reading the API documentation might not give this context.
That is where the tutorials are for.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorials/roundness_vs_circularity
